timeintervaltools.make_voice_from_nonoverlapping_intervals
==========================================================

.. autofunction:: abjad.tools.timeintervaltools.make_voice_from_nonoverlapping_intervals.make_voice_from_nonoverlapping_intervals
   :noindex:
